import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { CopyFolderRequest } from "../models/CopyFolderRequest";
import type { DeleteFolderBatchRequest } from "../models/DeleteFolderBatchRequest";
import type { DeleteFolderRequest } from "../models/DeleteFolderRequest";
import type { FolderDetails } from "../models/FolderDetails";
import type { FolderPath } from "../models/FolderPath";
import type { IncludeExternal } from "../models/IncludeExternal";
import type { IncludeFiles } from "../models/IncludeFiles";
import type { IncludePhysicalFolders } from "../models/IncludePhysicalFolders";
import type { IncludeVirtualFolders } from "../models/IncludeVirtualFolders";
import type { IterateFolderRecursively } from "../models/IterateFolderRecursively";
import type { ListFolderChildrenResponse } from "../models/ListFolderChildrenResponse";
import type { ListFolderCursor } from "../models/ListFolderCursor";
import type { ListFolderDryRun } from "../models/ListFolderDryRun";
import type { ListFolderItemLimit } from "../models/ListFolderItemLimit";
import type { ListFolderResponse } from "../models/ListFolderResponse";
import type { PutFolderRequest } from "../models/PutFolderRequest";
export declare class FolderService {
    /**
     * Creates or updates the folder specified by the `folderPath`.
     *
     * If the folder's ancestors do not exist, they will be created automatically (with empty FolderSettings).
     *
     * Note: you don't need to create folders before uploading files to them.
     * @param accountId
     * @param requestBody
     * @returns FolderDetails Success.
     * @throws ApiError
     */
    static putFolder(accountId: AccountId, requestBody: PutFolderRequest): Promise<FolderDetails>;
    /**
     * Gets the full details (e.g. permission, storage layer, etc.) for a folder.
     *
     * Returns an empty object if no settings have been configured for this folder.
     * @param accountId
     * @param folderPath
     * @returns FolderDetails Success.
     * @throws ApiError
     */
    static getFolderDetails(accountId: AccountId, folderPath: FolderPath): Promise<FolderDetails>;
    /**
     * Deletes a folder asynchronously.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFolder(accountId: AccountId, requestBody: DeleteFolderRequest): Promise<AsyncResponse>;
    /**
     * Lists the children (files and sub-folders) of a folder.
     *
     * Pagination is complete when the response `cursor` matches the request `cursor`.
     * @param accountId
     * @param folderPath
     * @param cursor
     * @param includeFiles
     * @param includeFolders
     * @param internal
     * @param limit
     * @returns ListFolderChildrenResponse Success.
     * @throws ApiError
     */
    static listFolderChildren(accountId: AccountId, folderPath: FolderPath, cursor?: ListFolderCursor, includeFiles?: IncludeFiles, includeFolders?: boolean, internal?: boolean, limit?: ListFolderItemLimit): Promise<ListFolderChildrenResponse>;
    /**
     * Lists the folder's contents.
     *
     * Pagination is complete when the response `cursor` is `null` or matches the request `cursor`.
     * @param accountId
     * @param folderPath
     * @param cursor
     * @param dryRun
     * @param includeExternalItems
     * @param includeFiles
     * @param includePhysicalFolders
     * @param includeVirtualFolders
     * @param limit
     * @param recursive
     * @returns ListFolderResponse Success.
     * @throws ApiError
     */
    static listFolder(accountId: AccountId, folderPath: FolderPath, cursor?: ListFolderCursor, dryRun?: ListFolderDryRun, includeExternalItems?: IncludeExternal, includeFiles?: IncludeFiles, includePhysicalFolders?: IncludePhysicalFolders, includeVirtualFolders?: IncludeVirtualFolders, limit?: ListFolderItemLimit, recursive?: IterateFolderRecursively): Promise<ListFolderResponse>;
    /**
     * Copies a folder asynchronously.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static copyFolder(accountId: AccountId, requestBody: CopyFolderRequest): Promise<AsyncResponse>;
    /**
     * Deletes multiple folders asynchronously.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFolderBatch(accountId: AccountId, requestBody: DeleteFolderBatchRequest): Promise<AsyncResponse>;
}
